Learn R Programming

SMMT (version 1.2.0)

download_municipality_inventory: Download municipality inventory

Description

This functions downloads and extracts the municipality inventory form a defined online source.

Usage

download_municipality_inventory(
  url = get_current_url(),
  path = getwd(),
  verbose = TRUE
)

Value

Character vector of length one. File path to the extracted XML file.

Arguments

url

Character vector of length one. Link to the zip file containing the municipality inventory.

path

Character vector of length one. Destination of extracted xml file.

verbose

Get a message after download about the content of the inventory.