This functions downloads and extracts the municipality inventory form a defined online source.
download_municipality_inventory(
url = get_current_url(),
path = getwd(),
verbose = TRUE
)Character vector of length one. File path to the extracted XML file.
Character vector of length one. Link to the zip file containing the municipality inventory.
Character vector of length one. Destination of extracted xml file.
Get a message after download about the content of the inventory.